function [ distribution, notFeasible, notFeasibleThrownOut ] = getDistribution( testFunctionName, alphaVaR, testSize , simulations, forceCreate)
%GETDISTRIBUTION gives the correct distribution of the test statistics
%given the parameters
%If the distribution does not exist, it is generated by the function
%getDistribution

%The distributions have the following names convention: 
%testFunctionName_testSize_alphaVaR
%example: testChristoffersen_500_0.05'

if nargin < 5
    forceCreate = 0;
end


expectedFileName = [fileparts(which('getDistribution')),'/',num2str(simulations),'_sims/',testFunctionName, '_', num2str(testSize), '_', strrep(num2str(alphaVaR), '.', '')];
expectedFileName2 = [testFunctionName, '_', num2str(testSize), '_', strrep(num2str(alphaVaR), '.', '')];

fileInfo = struct2cell(dir([fileparts(which('getDistribution')),'/',num2str(simulations),'_sims/']));
fileList = fileInfo(1, :);
names = fileList(3:size(fileList, 2));
fileNames = strrep(names, '.mat', '');

if ismember(expectedFileName2 ,fileNames) && ~forceCreate
    load(expectedFileName);
    distribution = distr;
    notFeasible = not_Feasible;
    notFeasibleThrownOut = not_FeasibleThrownOut;
else
    savefile = [expectedFileName, '.mat'];
    warning('Distribution not found, generating...');
    [distr, not_Feasible, not_FeasibleThrownOut] = GenerateDistribution(testFunctionName, alphaVaR, testSize, simulations);
    save(savefile, 'distr', 'not_Feasible', 'not_FeasibleThrownOut');
    distribution = distr;
    notFeasible = not_Feasible;
    notFeasibleThrownOut = not_FeasibleThrownOut;
end
end