function [ gofResults ] = gofFiniteSample(testName, alphaVaR, dataLength, part)
%GOFFINITESAMPLE Tests by goodness of fit if the generated distribution for
%testName, alphaVaR, dataLength follows the h0Distribution
%   testName:       {STRING} name of tests e.g. {'testWeibullDisc', 'testChristoffersen'}. 'all' gives all tests
%   alphaVaR:       DOUBLE test significance level (0.01 0.05 0.1). Vector gives
%                   for all VaR levels in the vector
%   dataLength:     INT length of the returns/VaR-series the distribution is
%                   made for. Vector gives for all dataLengths in the vector
%   part:           INT part of distribution to test. 1 -> whole
%                   distribution. 0.10: Upper 10% of distribution
settings = {testName, alphaVaR, dataLength};
testResults = cell(length(testName), length(alphaVaR), length(dataLength));

allTestNames = {'testChristoffersen'
    , 'testWeibullDisc'
    , 'testKupiec'
    , 'testWeibullCon'
    
    , 'testGeometricCC'
    , 'testWeibullConCC'
    , 'testWeibullDiscCC'
    , 'testWeibullDiscHaasCC'
    , 'testChristoffersenCC'
    
    , 'testDQLogCC1'
    
    , 'testDQLogInd'
        
    , 'testDQLogCC'
    };

for i = 1:4
    h0Distributions.(allTestNames{i}) = {'chi2cdf', 1};
end
for i = 5:9
    h0Distributions.(allTestNames{i}) = {'chi2cdf', 2};
end
h0Distributions.(allTestNames{10}) = {'chi2cdf', 3};
h0Distributions.(allTestNames{11}) = {'chi2cdf', 6};
h0Distributions.(allTestNames{12}) = {'chi2cdf', 7};
  
if(strcmp(testName, 'all'))
    testName = allTestNames;
end

for i = 1:length(testName)
    for j = 1:length(alphaVaR)
        for k = 1:length(dataLength)
            fprintf([testName{i}, ' ', num2str(alphaVaR(j)), ' ', num2str(dataLength(k)), ' pvalue = ']);
            testSettings = h0Distributions.(testName{i});
            df = testSettings{2};
            distribution = getDistribution(testName{i}, alphaVaR(j), dataLength(k), 50000, 0);
            distribution = distribution(distribution > 0);
            distribution = distribution(distribution > chi2inv(1 - part, df));
            x = chi2cdf(distribution, df);

            n = length(x);
            edges = linspace(1 - part,1,11);
            expectedCounts = (n/(length(edges) - 1))*ones(10, 1);
            [h,p,st] = chi2gof(x,'edges',edges,'expected',expectedCounts);
            
            testResults{i, j, k} = {x, p};
            fprintf([num2str(p), '\n']);
        end
    end
end

gofResults = {testResults, settings};

end