function [ pvalue ] = testDistribution( testFunctionName, alphaVaR, testSize, simulations)
%TESTDISTRIBUTION Checks if the finite sample distribution follows the
%underlying asymptotic distribution.
%INPUT:
%testFunctionName: String with the name of the test, e.g. testDQLogInd
%alphaVaR: 0.01 0.05 or 0.1
%testSize: 100 250 500 750 1000 1250 or 1500
%simulations: 10000 or 50000

fileNames = {testFunctionName};

if(strcmp(testFunctionName, 'all'))
    fileNames = {'testKupiec' 'testChristoffersen' 'testDQLogInd' 'testDQLogInt' 'testWeibullCon' 'testWeibullDisc'};
end

for i = 1:length(fileNames)
    testFunctionName = fileNames{i};
    if(strcmp(testFunctionName, 'testDQLogInd'))
        degreesOfFreedom = 6;
        testDistributionName = 'chi2cdf';
    elseif(strcmp(testFunctionName, 'testDQLogInt'))
        degreesOfFreedom = -1;
        testDistributionName = 'normal';
    else 
        testDistributionName = 'chi2cdf';
        degreesOfFreedom = 1;
    end

    distribution = getDistribution(testFunctionName, alphaVaR, testSize, simulations, 0);

    if (strcmp(testDistributionName, 'chi2cdf'))
        figure
        hist(distribution, 100);
        title(['Distribution ', testFunctionName, ' alphaVaR = ', num2str(alphaVaR), ' testSize = ', num2str(testSize), ' simulations = ', num2str(simulations)]);

        figure
        uniformDistribution = chi2cdf(distribution, degreesOfFreedom);
        n = length(uniformDistribution);
        edges = linspace(0,1,11);
        expectedCounts = n * diff(edges);
        [h,p,st] = chi2gof(uniformDistribution,'edges',edges,...
                         'expected',expectedCounts);    
        arr = struct2array(st);
        hist(uniformDistribution);
        title(['Cumulative ', testFunctionName, ' alphaVaR = ', num2str(alphaVaR), ' Chi2Stat = ', num2str(arr(1)), ' p = ', num2str(p)]);

        pvalue = p;
   else
        figure
        hist(distribution, 100);
        uniformDistribution = normcdf(distribution, 0, 1);
        n = length(uniformDistribution);
        buckets = 10;
        edges = linspace(0,0.5,buckets + 1);
        expectedCounts = n/buckets * ones(1, buckets);
        [h,p,st] = chi2gof(uniformDistribution,'edges',edges,'expected',expectedCounts);    
        arr = struct2array(st);

        title(['Distribution ', testFunctionName, ' alphaVaR = ', num2str(alphaVaR), ' testSize = ', num2str(testSize), ' simulations = ', num2str(simulations)]);

        figure
        hist(uniformDistribution, 10);
        title(['Cumulative ', testFunctionName, ' alphaVaR = ', num2str(alphaVaR), ' Chi2Stat = ', num2str(arr(1)), ' p = ', num2str(p)]);

        pvalue = p;
    end
end

end

