function [ pUC, pIND, pMIX ] = testBerkowitz( zSeries, finiteSampleDistribution, testStatisticsOutput )

% BERKOWITZ
% Tester UC, CC og MIX ved bruk av CDF.
% Tar inn z-serie (transform fra CDF) og tester UC, CC og MIX


[~, fval0] = fminsearch(@(vars) BerkowitzLLF(zSeries, vars(1), vars(2), vars(3)), [0 1 0]);
llf1 = - fval0;

[~, fval0] = fminsearch(@(vars) BerkowitzLLF(zSeries, 0, 1, vars(1)), [0]);
llf2 = - fval0;

[~, fval0] = fminsearch(@(vars) BerkowitzLLF(zSeries, vars(1), vars(2), 0), [0 1]);
llf3 = - fval0;

llf4 = - BerkowitzLLF(zSeries, 0, 1, 0);


LRuc = 2*(llf1 - llf2);
LRind = 2*(llf1 - llf3);
LRmix = 2*(llf1 - llf4);


if( nargin > 2 && testStatisticsOutput)
    pUC = LRuc;
    pIND = LRind;
    pMIX = LRmix;
elseif(nargin > 1 && ~isempty(finiteSampleDistribution))
    pUC = FindP(LRuc, finiteSampleDistribution(1,:));
    pIND = FindP(LRuc, finiteSampleDistribution(2,:));
    pMIX = FindP(LRuc, finiteSampleDistribution(3,:));
else
    pUC = 1-chi2cdf(LRuc,2);
    pIND = 1-chi2cdf(LRind, 1);
    pMIX = 1-chi2cdf(LRmix, 3);
end

end

