function [ pValue, notFeasibleThrownOut ] = testDQLogCC(returns, varSeries, alphaVar, finiteSampleDist, testStatisticsOutput )

k=3;				% Number of lagged hits to be included in the test.

notFeasibleThrownOut = 0;

%% CREATE breaches FUNCTION
breaches = returns<-varSeries;

if(sum(breaches(k+1:length(breaches))) <= 1 ) 
	pValue = nan;
    notFeasibleThrownOut = 1;
	return;
end

%% REGRESSIONS AND TESTS 1
if(~isempty(varSeries))
    Z = zeros(length(varSeries)-k, 2*k);

    for s = 1:k
       Z(:,s) = breaches(k+1-s:length(varSeries)-s);
    end
    for s = 1:k
       Z(:,s+k) = varSeries(k+1-s:length(varSeries)-s);
    end
else
    Z = zeros(length(varSeries)-k, k);
    Z(:,1) = ones(length(varSeries)-k,1)*log(alphaVar/(1-alphaVar));
    for s = 1:k
       Z(:,s) = breaches(k+1-s:length(varSeries)-s);
    end
end
%% REGRESSIONS AND TESTS 2

%Modell with all terms
[b,dev,stats] = glmfit(Z,breaches(k+1:length(breaches)),'binomial','link','logit');

%Modell with all terms except locked constant
%[b2,dev2,stats2] = glmfit(Z,breaches(k+1:length(breaches)),'binomial','link','logit','constant','off','offset',log(alphaVar/(1-alphaVar))*ones(length(breaches)-(k),1));

%Model with nothing constant term
%[btemp,devtemp,statstemp] = glmfit(zeros(length(k+1:length(breaches)),1),breaches(k+1:length(breaches)),'binomial','link','logit','constant','off');

%Model with locked constant only
%[btemp2,devtemp2,statstemp2] = glmfit(zeros(length(k+1:length(breaches)),1),breaches(k+1:length(breaches)),'binomial','link','logit','constant','off','offset',log(alphaVar/(1-alphaVar))*ones(length(breaches)-(k),1));

%Calculate deviance for a logit model with only locked constant
N=1;
y = breaches(k+1:length(breaches));
mu = ones(length(breaches)-k,1)*alphaVar;

di = 2*N.*(y.*log((y+(y==0))./mu) + (1-y).*log((1-y+(y==1))./(1-mu)));
devtemp2 = sum(di);

G_stat = devtemp2-dev;

if(G_stat<0)
   pValue = nan;
   return;
end

if(testStatisticsOutput == 1) 
    pValue = G_stat;
    return
else
    if(~isempty(finiteSampleDist)) 
        try
            p_ind = FindP(G_stat,finiteSampleDist);
        catch err
            disp(['DQLogCC gets: ',err.message]);
        end
    else
        p_ind = 1-chi2cdf(G_stat,2*k+1);
    end
end

%% OUTPUT
pValue = p_ind;
