function [ pValue  ] = testGeometricInd( returns, varSeries, alphaVar, finiteSampleDist, testStatisticsOutput )

    % Find breaches
    breaches = find(returns < - varSeries);

    % Find durations, minimum 0 (day after day)
    durations = diff(breaches) - 1;
    
    % If no breaches, return NaN
    if(isempty(durations))
        pValue = NaN;
        return
    end
    
    % Add censoring, first and last duration will be censored observations
    % -1 value will not affect MLE (we have no censoring)
    durations2 = zeros(2 + length(durations), 1);
    durations2(1) = min(breaches) - 1 - 1; % Minus first observation, minus 1
    durations2(length(durations2)) = length(returns) - max(breaches) - 1; % Minus last observation, minus 1
    
    for j=1:length(durations)
        durations2(j+1)=durations(j);
    end
    
        
    
    % estimate a and b
    [x0, LL, exitflag0] = fminsearch(@(qANDb) testGeometricMLE(durations2, qANDb(1),qANDb(2)), [alphaVar, 0]);
    
    if(nargin > 4 && testStatisticsOutput == 2)
        pValue = x0(2);
        return;
    end
    
    if(nargin > 4 && testStatisticsOutput == 3)
        pValue = x0(1);
        return;
    end
    
    
    lle1 = -LL;
    
    if(exitflag0 < 1)
        pValue = NaN;
        return;
    end
      
    % estimate a and set b=1
    [~, LL] = fminsearch(@(qANDb) testGeometricMLE(durations2, qANDb(1), 0), [alphaVar]);
    
    lle0 =  -LL;
    
    LR = -2*(lle0 - lle1);
                
    if(nargin > 4 && testStatisticsOutput == 1) 
        pValue = LR;
    else
        if(nargin > 3 && ~isempty(finiteSampleDist)) 
            try
                pValue = FindP(LR,finiteSampleDist);
            catch err
                disp(['WeibullGeometricInd gets: ',err.message]);
            end
        else
            pValue = 1 - 0.5*chi2cdf(LR, 2)-0.5*chi2cdf(LR, 1);
        end
    end

end


