function [ pValue ] = testVQRCC( returns, varSeries, alphaVar, finiteSampleDist, testStatisticsOutput )

openR;
putRdata('returns',returns);
putRdata('varSeries',-varSeries);
putRdata('alphaVar', alphaVar);
evalR('setwd("D:/NTNU/Master/Masteroppgave/R")');
evalR('source("vqr_test.R")');
evalR('testStat <- vqr_test( returns, varSeries, alphaVar)');
testStat = getRdata('testStat');
closeR;

pValue = testStat;

%{
clear;

file_name  = 'returns_sp500.csv';
file_name2 = 'var_normal.csv';

%Select the VaR nominal level
tau_VAR = 0.95;

tau_init   = 0.01;
tau_end    = 0.99;
step_quant = 0.01;

%Critical Value from a chi-squared with 2 degrees of freedom at 5% = 6
crit_value = 6;

y = -load('returns_sp500.csv');
returns = y;
returns_sq = y.*y;
y_orig = returns;
y = y_orig;
T = length(y);

zz = -load('var_normal.csv');
va_risk_orig  = zz;
va_risk_orig2 = zz;

delta_y = diff(y_orig);
delta_y_orig = delta_y;

n_01 = round(1 + (0.01-tau_init) / step_quant); %Round to get integer
n_05 = round(1 + (0.05-tau_init) / step_quant);
n_10 = round(1 + (0.10-tau_init) / step_quant);
n_25 = round(1 + (0.25-tau_init) / step_quant);
n_75 = round(1 + (0.75-tau_init) / step_quant);
n_90 = round(1 + (0.90-tau_init) / step_quant);
n_95 = round(1 + (0.95-tau_init) / step_quant);
n_99 = round(1 + (0.99-tau_init) / step_quant);
n_tau_VAR = round(1 + (tau_VAR-tau_init) / step_quant);

disp('********************************************************************************');
disp('** Evaluating Value-at-Risk models via quantile regressions.                  **');
disp('********************************************************************************');
disp('')

q_final = 1;
q = q_final - 1;

%maximum lag used in long run covariances estimations
%truncation lag
m = round((4*(length(y)/100)^(1/3)));

%Selected Quantiles: 'step_quant' is calculated from the 'n_quantiles' parameter
%tau = seq(0.1, 0.9, by=step_quant)
tau = [tau_init : step_quant : tau_end];

y_aux = nan(T, 1);
va_risk_aux = nan(T, 1);

for t = 1:T
    y_aux(t) = returns(t);
    va_risk_aux(t) = va_risk_orig(t);
end

y = 0;
y = y_aux;
va_risk = va_risk_aux;
q = q_final - 1;

Un_o = 0;
alpha1_hat_o = 0;
alpha0_hat_o = 0;
f_F_hat = 0;
tn = 0;
I = 0;
V_til = 0;
V_hat = 0;
Ln = 0;
u = 0;
phi = 0;
ker = 0;
%cov_w_phi = 0
sigma_w_phi = 0;
delta2 = 0;

Y = [y va_risk];
q = (q_final - 1);

%____________________________________________________________________________________
%                                  Fitting QR model (1):
%
%                                  Rt = ao(ut) + a1(ut)*Vt
%
%____________________________________________________________________________________

alpha_hat_o = nan(length(tau), q+2);

for quantil = 1:length(tau)
    fit_QAR = quantreg(Y(:, 2), Y(:, 1), tau(quantil));
    alpha_hat_o(quantil,:) = fliplr(fit_QAR');
end

disp('');
disp('** Results of the Quantile Regression estimation **');
disp('');

aux1 = [tau' alpha_hat_o];

disp('Estimated alpha coefficients');
disp(aux1);
disp('');

%____________________________________________________________________________________%
%                            Compute the conditional quantiles 
%____________________________________________________________________________________%

ut_hat = nan(T, 1); %Recover the Ut process by using the estimated coefficients.
y_quantile = nan(T, length(tau));
y_recover = nan(T, 1);
q_dist = nan(T, 1);
q_final = 1;

for n_quantile = 1:length(tau)
    for t = 1:T
        a1 = alpha_hat_o(n_quantile, 1);
        a2 = alpha_hat_o(n_quantile, 2);
        y_quantile(t, n_quantile) = a1 + a2*va_risk(t);
    end
end

for t = 1:T
    for n_quantile = 1:length(tau)
        if(y_orig(t) < y_quantile(t, n_quantile))
            if(isnan(ut_hat(t, 1)))
                ut_hat(t, 1) = tau_init + (n_quantile - 1)*step_quant;
            end
        end
        
        if(y_orig(t) == y_quantile(t, n_quantile))
            if(isnan(ut_hat(t, 1)))
                ut_hat(t,1) = tau_init + (n_quantile - 1)*step_quant;
            end
        end
    end
    
    if(isnan(ut_hat(t, 1 )))
        ut_hat(t, 1) = tau_end;
    end
end

a_coef = nan(T, 3);

for t = 1:T
    n_quantile = round(1 + (ut_hat(t, 1) - tau_init)/step_quant); %La inn round for  f heltall
    a1 = alpha_hat_o(n_quantile, 1);
    a2 = alpha_hat_o(n_quantile, 2);
    
    a_coef(t, 1) = a1;
    a_coef(t, 2) = a2;
    
    y_recover(t, 1) = a1 + a2*va_risk(t);
end

%____________________________________________________________________________________
%                      Compute the number of Hits of the VaR
%____________________________________________________________________________________

hit_q99 = nan(T ,1);
hit_q95 = nan(T ,1);
hit_q90 = nan(T ,1);
hit_q75 = nan(T ,1);
hit_q25 = nan(T ,1);
hit_q10 = nan(T ,1);
hit_q05 = nan(T ,1);
hit_q01 = nan(T ,1);
hit_var = nan(T ,1);

cont_q01 = 0;
cont_q05 = 0;
cont_q10 = 0;
cont_q25 = 0;
cont_q75 = 0;
cont_q90 = 0;
cont_q95 = 0;
cont_q99 = 0;

cont_var = 0;

for t = 1:T
    hit_q01(t, 1) = 0;
    hit_q05(t, 1) = 0;
    hit_q10(t, 1) = 0;    
    hit_q25(t, 1) = 0;
    hit_q75(t, 1) = 0;
    hit_q90(t, 1) = 0;
    hit_q95(t, 1) = 0;
    hit_q99(t, 1) = 0;
    hit_var(t, 1) = 0;
    
    if(y_quantile(t, n_01) < y_orig(t))
        hit_q01(t, 1) = 1;
        cont_q01 = cont_q01 + 1;
    end
    
    if(y_quantile(t, n_05) < y_orig(t))
        hit_q05(t, 1) = 1;
        cont_q05 = cont_q05 + 1;
    end
    
    if(y_quantile(t, n_10) < y_orig(t))
        hit_q10(t, 1) = 1;
        cont_q10 = cont_q10 + 1;
    end
    
    if(y_quantile(t, n_25) < y_orig(t))
        hit_q25(t, 1) = 1;
        cont_q25 = cont_q25 + 1;
    end
    
    if(y_quantile(t, n_75) < y_orig(t))
        hit_q75(t, 1) = 1;
        cont_q75 = cont_q75 + 1;
    end
    
    if(y_quantile(t, n_90) < y_orig(t))
        hit_q90(t, 1) = 1;
        cont_q90 = cont_q90 + 1;
    end
    
    if(y_quantile(t, n_95) < y_orig(t))
        hit_q95(t, 1) = 1;
        cont_q95 = cont_q95 + 1;
    end
    
    if(y_quantile(t, n_99) < y_orig(t))
        hit_q99(t, 1) = 1;
        cont_q99 = cont_q99 + 1;
    end
    
    if (va_risk(t) < y_orig(t))
        hit_var(t, 1) = 1;
        cont_var = cont_var + 1;
    end
end

cont_q01 = cont_q01 / T;
cont_q05 = cont_q05 / T;
cont_q10 = cont_q10 / T;
cont_q25 = cont_q25 / T;
cont_q75 = cont_q75 / T;
cont_q90 = cont_q90 / T;
cont_q95 = cont_q95 / T;
cont_q99 = cont_q99 / T;

cont_var_2 = cont_var / T;

disp('');
disp('Percentage of Hits (Var)');
disp(cont_var_2*100);
disp('');    
    
%____________________________________________________________________________________
%                             Compute the VQR test
%____________________________________________________________________________________
% print("Hypothesis Test: alpha_0 = 0 & alpha_1 = 1")
% Bofinger bandwidth (if tau=0.99) 
% fit1 <- summary(rq(Y[,1] ~ Y[,2:(q+2)], tau = tau_VAR), method="fn" , hs=FALSE, se="nid" , cov=TRUE)
% Hall Sheather bandwidth 

openR;
evalR('library(stats)');
evalR('library(quantreg)');
evalR('library(nlme)');
evalR('library(grDevices)');
putRdata('Y', Y);
putRdata('tau_VAR', tau_VAR);

evalR('fit1 <- summary(rq(Y[,1] ~ Y[,2:2], tau = tau_VAR), method="fn" , se="nid" , cov=TRUE)');
evalR('a = fit1$cov');

A = getRdata('a');

evalR('a = Y[,1]');
evalR('a = Y[,2:(q+2)]');
a = getRdata('a');


%A = quantreg(Y(:, 2), Y(:, 1), tau_VAR);
%a1 = A(2);
%a2 = A(1);

%M = nan(2, 1);
%M(1, 1) = a1;
%M(2, 1) = (a2 - 1);

%aux7 = nan(2, 2);
%ident = nan(2, 2);
%ident(1, 1) = 1;
%ident(1, 2) = 0;
%ident(2, 1) = 0;
%ident(2, 2) = 1;

%Y = [varSeries ones(length(returns),1) returns];
%Z = [varSeries returns];

%arg = rq(Y(:,1:2), Y(:,3), alphaVar)
%[a,b]=quantreg(Y(:,1:2), Y(:,3), alphaVar)
%quantreg(Y(:,1:2), Y(:,3), alphaVar)
%hold on
%[beta tstats VCboot itrat PseudoR2 betaboot]=quantilereg(Z(1:650,2),Z(1:650,1),  alphaVar);

%const = -0.00269;
%slope = 0.86953;
%rqLine = sort(varSeries)*slope+const;
%plot(sort(varSeries),rqLine)
%}
%{
a1 = -arg(2);
a2 = arg(1);
%}
%{
# print("Hypothesis Test: alpha_0 = 0 & alpha_1 = 1")
# Bofinger bandwidth (if tau=0.99) 
# fit1 <- summary(rq(Y[,1] ~ Y[,2:(q+2)], tau = tau_VAR), method="fn" , hs=FALSE, se="nid" , cov=TRUE)
# Hall Sheather bandwidth 
fit1 <- summary(rq(Y[,1] ~ Y[,2:(q+2)], tau = tau_VAR), method="fn" , se="nid" , cov=TRUE)

M_aux = matrix(nrow = 2 , ncol=1)
M_aux = fit1$coefficients
a1 = M_aux[1,1]
a2 = M_aux[2,1]

# print("Coefficients")
# print(a1)
# print(a2)

M = matrix(nrow = 2 , ncol=1)
M[1,1] = a1
M[2,1] = (a2-1)

# print("M = RB - r")
# print(M)
# print("Method: nid")
# print(fit1)
# print("Cov")
# Cov from the R code is the estimated asymptotic covariance matrix given by (tau*(1-tau)*Hinv*J*Hinv)

# print(fit1$cov)
# print("Hinv")
# print(fit1$Hinv)
# print("J")
# print(fit1$J)

aux7  = matrix(nrow = 2 , ncol = 2)
ident = matrix(nrow = 2 , ncol = 2)
ident[1,1]=1
ident[1,2]=0
ident[2,1]=0
ident[2,2]=1
aux7 = solve(ident,fit1$cov)
aux8 <- aux7[1,1]*aux7[2,2] - aux7[1,2]*aux7[2,1]

# old way: inv_cov = solve(fit1$cov)
inv_cov = matrix(nrow = 2 , ncol = 2)

aa = aux7[1,1]
bb = aux7[1,2]
cc = aux7[2,1]
dd = aux7[2,2]
inv_cov[2,1] = 1/(bb-aa*dd/cc)
inv_cov[2,2] = 1/(dd-cc*bb/aa)
inv_cov[1,1] = -inv_cov[2,1]*dd/cc
inv_cov[1,2] = -inv_cov[2,2]*bb/aa

# print("inv_asymp_covar")
# print(inv_cov)
# print("-------------------")
print("p-value")

statistic = (t(M)) %*% inv_cov %*% M 
# print(statistic[1,1])
p.value.ucqr = 1-pchisq(statistic[1,1], df=2)
print(p.value.ucqr)
%}
end