function [ pValue, notFeasibleThrownOut ] = testWeibullConCC(returns, varSeries, alphaVar, finiteSampleDist, testStatisticsOutput)
    %
    %BACKTESTWEIBULL with coverage.
    %   Detailed explanation goes here

    breaches = find(returns < - varSeries);
    
    notFeasibleThrownOut = 0;

    % Need at least two breaches
    if numel(breaches) < 2
        pValue = NaN;
        notFeasibleThrownOut = 1;
        return;
    end

    startCensoring = ~(breaches(1) == 1); % Check if first breach happens on first index
    endCensoring = ~(breaches(length(breaches)) == length(returns)); % check if last breach happens on last index

    durations = diff(breaches);
    durations2 = zeros(startCensoring + endCensoring + length(durations), 1);

    if startCensoring
        durations2(1) = min(breaches) - 1;
    end

    if endCensoring
        durations2(length(durations2)) = length(returns) - max(breaches);
    end

    for j=1:length(durations)
        durations2(j+startCensoring)=durations(j);
    end


    censoring = zeros(length(durations2), 1);
    censoring(1) = startCensoring;
    censoring(length(censoring)) = endCensoring;


    % Likelihood under H1
    parmhat = wblfit(durations2, 0.01, censoring);
    llr1 = - wbllike(parmhat, durations2, censoring);

    if(isnan(llr1))
        pValue = NaN;
        return;
    end

    % To get B avg
    if( nargin > 4 && testStatisticsOutput == 2)
        pValue = parmhat(2);
        return;
    end

    % Likelihood under H0
    %parmhat = expfit(durations2, alphaVar, censoring);
    llr0 = - explike(1/alphaVar, durations2, censoring);

    % Likelihood under H0
    % TODO: Kan erstatte aNDb(2) med 1.125 som er ~ asymptotisk verdi
    % Men hvordan hndtere andre sample sizes? Bruke 1 (expfit/explike)?
    %[~, LL, exitflag0] = fminsearch( @(aANDb) - log( 1- wblcdf( durations2(1), 1/aANDb(1), aANDb(2)) ) * startCensoring - log( 1- wblcdf( durations2( length(durations2) ), 1/aANDb(1), aANDb(2)) ) * endCensoring - sum( log( wblpdf(durations, 1/aANDb(1), aANDb(2)) ) ), [alphaVar, 1]);

    %llr0 = - LL;

    LR = -2 * (llr0 - llr1);



    if(nargin > 4 && testStatisticsOutput == 1) 
        pValue = LR;
    else
        if(~isempty(finiteSampleDist))
            try
                pValue = FindP(LR,finiteSampleDist);
            catch err
                disp(['WeibullConCC gets: ',err.message]);
            end
        else
            pValue = 1 - chi2cdf(LR, 2);
        end
    end


end
 