function [ p ] = UnconditionalProbability( probabilities, uProb )
%UNCONDITIONALPROBABILITY Gives the long term probability given a set of
%conditional probabilities and wanted unconditional probability.
%   Detailed explanation goes here

n = length(probabilities);

% n states + rest state + rest state x conditional prob given rest state
A = zeros(n+2,n+2);
v = zeros(n+2,1);

% All states sum to 1
v(n+1,1) = 1;
for i=1:n   
    A(n+1,i) = 1;    
end
A(n+1,n+1) = 1; % including rest state

% SUM( State Prob x Cond Prob ) = uncond prob
v(n+2,1) = uProb;
for i=1:n   
    A(n+2,i) = probabilities(i);   
end
A(n+2,n+2) = 1; % rest state x cond prob rest state


% Steady state probabilities

% First state
A(1,1) = 1 - probabilities(1);

for i=2:n
    A(1,i) = - probabilities(i);
end

A(1,n+2) = -1;

% Rest of the states not including rest state
for i=2:n
    A(i,i) = 1;
    A(i,i-1) = probabilities(i-1) - 1;
end


x = A\v;
p = x(n+2)/x(n+1);


end

