function [asymptoticValues] = RunAsymptotic( runNr )
       
    %% Legg alle filer i path som ligger under Matlab
    currentDir = fileparts(which('RunAsymptotic'));

    addpath( genpath([currentDir, '/../../External Scripts']) );
    addpath( genpath([currentDir, '/../../MFEToolbox']) );
    addpath( genpath([currentDir, '/../../Under Progress']) );
    
%% Bruk alle kjernene!    
    matlabpool;

%% Setter random-seeden til runNr
    spmd 
        RandStream.setDefaultStream(RandStream('mt19937ar', 'Seed', runNr + labindex*1000));
    end    
    
    %% Scripts og funksjoner vi nsker  kjre
    start = tic;
    warning off all;
    %randomSeed = rng('shuffle');
    %randomSeed = rng(runNr);
    
    %tests = {'testChristoffersen', 'testKupiec', 'testWeibullCon', 'testWeibullDisc', 'testDQLogInd', 'testDQLogInt', 'testDQLogCC','testChristoffersenCC', 'testWeibullConCC', 'testWeibullDiscCC', 'testBinomial', 'testDQLogCC1'};  
    tests = {'testChristoffersenCC', 'testDQLogCC','testWeibullConCC', 'testWeibullDiscCC', 'testGeometricCC'};  
    
    dataLengths = [100 250 500 750 1000 1250 1500];
    %dataLengths = [100];
    alphaVar = [0.01 0.05 0.10];
    %alphaVar = [0.10];
    alphaTest = 0.10;
    sims = 50000;
      
    asymptoticValues = zeros(length(dataLengths),length(tests),length(alphaVar));
    feasabilityValues = zeros(length(dataLengths),length(tests),length(alphaVar));
        
    %%
    for alphaVari = 1:length(alphaVar)
        for testsi = 1:length(tests)
            fh = str2func(tests{testsi});
            parfor dataLengthsi = 1:length(dataLengths)
                disp([tests{testsi},' ',num2str(alphaVar(alphaVari)),' ',num2str(dataLengths(dataLengthsi))]);
                statCounter=0;
                feasabilityCounter=0;
                %dist= getDistribution(tests{testsi},alphaVar(alphaVari),dataLengths(dataLengthsi),50000,0);
                for i=1:sims
                    nextStatistic = NaN;
                    while isnan(nextStatistic)
                        feasabilityCounter = feasabilityCounter+1;
                        [returns var] = generateSeries(alphaVar(alphaVari), dataLengths(dataLengthsi));
                        %nextStatistic = fh(returns,var,alphaVar(alphaVari),dist,0);
                        nextStatistic = fh(returns,var,alphaVar(alphaVari),[],0);
                    end
                    if(nextStatistic < alphaTest)
                        statCounter = statCounter+1;
                    end
                end
                asymptoticValues(dataLengthsi,testsi, alphaVari) = statCounter/sims;
                feasabilityValues(dataLengthsi,testsi, alphaVari) = sims/feasabilityCounter;
            end
        end
    end
    
    %% Avslutter Matlab (slik at vi ikke bruker undvendige ressurser p Solstorm
    
    warning on all;
    save(['asymptoticValues_', num2str(runNr), '.mat'], 'asymptoticValues')
    save(['feasabilityValues_', num2str(runNr), '.mat'], 'feasabilityValues')
    
    matlabpool close;
    toc(start);
    
    exit;
    

end

