function [ output_args ] = RunCBP(runNr)

disp(['Running..', num2str(runNr)]);

matlabpool;

currentDir = fileparts(which('RunCBP'));

addpath( genpath([currentDir, '/../../External Scripts']) );
addpath( genpath([currentDir, '/../../MFEToolbox']) );
addpath( genpath([currentDir, '/../../Under Progress']) );

lengths = [100 250 500 750 1000 1250 1500];
alphaVaRs = [0.01 0.05 0.10];
tests = {'testChristoffersen', 'testWeibullConCC', 'testGeometricCC', 'testDQLogCC', 'testKupiec'};

sims = 500;
alphaTest = 0.10;
lookback = 250;
businessLinesParams = [3.808 -0.245 0.7495 0.1552 0.5469; 3.3183 0.5031 0.9284 0.0524 0.2154; 6.9117 -0.9616 0.8728 0.0261 0.2127; 4.7017 0.0928 0.9153 0.0723 1.6532];

%%

allDistributions = cell(length(tests), length(alphaVaRs), length(lengths));

for i = 1:length(tests)
    for j = 1:length(alphaVaRs)
        parfor k = 1:length(lengths)
            allDistributions{i, j ,k} = getDistribution(tests{i}, alphaVaRs(j), lengths(k), 50000, 0);
        end
    end
end
disp('Distributions loaded');

%%
tic;
allReturns = zeros(max(lengths)+lookback, sims, size(businessLinesParams, 1));

for i = 1:size(businessLinesParams, 1)
    parfor j = 1:sims
        allReturns(:, j, i) = generateNGARCHt(max(lengths), lookback, businessLinesParams(i, 1), businessLinesParams(i, 2), businessLinesParams(i, 3), businessLinesParams(i, 4), businessLinesParams(i, 5));
    end
end

disp('Returns generated');
toc;
%%

allVarSeries = cell(sims, size(businessLinesParams, 1), length(lengths), length(alphaVaRs));

for i = 1:size(businessLinesParams, 1)
    for j = 1:sims
        for k = 1:length(lengths)
            returns = allReturns(:, j, i);
            returns = returns(1 : lengths(k) + lookback);
            parfor l = 1:length(alphaVaRs)
                allVarSeries{j, i, k, l} = generateHistoricalVaR(returns, alphaVaRs(l), lookback);
            end
        end
    end
end
disp('VaR-series generated');
toc;

%%

allRejections = zeros(size(businessLinesParams, 1), length(tests), length(lengths), length(alphaVaRs), sims);
allSims = zeros(size(businessLinesParams, 1), length(tests), length(lengths), length(alphaVaRs), sims);

for i = 1:sims
    for j = 1:size(businessLinesParams, 1)
        returns = allReturns(:, i, j);
        for k = 1:length(lengths)
            ret = returns(lookback + 1 : lengths(k) + lookback);
            for l = 1:length(alphaVaRs)
                var = allVarSeries{i, j, k, l};
                for m = 1:length(tests)
                    fh = str2func(tests{m});
                    pValue = fh(ret, var, alphaVaRs(l), allDistributions{m, l, k}, 0);
                    if(isnan(pValue))
                        continue;
                    else
                        allSims(j, m, k, l, i) = allSims(j, m, k, l, i) + 1;
                    end
                        
                    if(pValue < alphaTest)
                        allRejections(j, m, k, l, i) = allRejections(j, m, k, l, i) + 1;
                    end
                end
            end
        end
    end 
end

disp('Powers generated');
toc;

%%
matlabpool close;

savePath = [fileparts(which('getPow')) , '/storedRuns/CBP/'];
savefile = [savePath, 'storageCell_Run_', num2str(rand()) ,'_', num2str(runNr), '.mat'];
disp('Saving file...');
disp(savefile);
save(savefile, 'allSims', 'allRejections', 'tests', 'lengths', 'alphaVaRs');
disp('Done');

exit;
end