function [storageCell] = RunFunctionLocal( runNr )

    %% Bruk alle kjernene!    
    %matlabpool;

    %% Legg alle filer i path som ligger under Matlab
    currentDir = fileparts(which('RunFunction'));

    addpath( genpath([currentDir, '/../../External Scripts']) );
    addpath( genpath([currentDir, '/../../MFEToolbox']) );
    addpath( genpath([currentDir, '/../../Under Progress']) );
    
    start = tic;
    
    %% Scripts og funksjoner vi nsker  kjre
    %  Bruk runNr til  spesifisere hva slags type jobb som skal kjres
    
    %runNr =  + runNr; % Unng overskriving, behold gamle filer    
    sims = 200;    
    storageCell = cell(3, 2);       
    nrSims = @(sims, nrP, nrV, nrPhi, nrLengths, nrTests) sims*( nrP + 1 + nrV + nrPhi + nrPhi*nrV)*nrLengths*nrTests;
    
    warning off all;
    
    tests = {'testChristoffersen', 'testKupiec', 'testWeibullCon', 'testWeibullDisc', 'testDQLogInd', 'testDQLogInt', 'testDQLogCC','testChristoffersenCC', 'testWeibullConCC', 'testWeibullDiscCC', 'testBinomial'};
    %tests = {'testKupiec'};
    underlyingProcesses = {'uniform', 'normal', 'studentt', 'garchnormal','garchstudentt'};
    %underlyingProcesses = {'uniform'};
    lookback = 1000;
    dataLengths = [100 250 500 750 1000 1250 1500];
    alphaTest = 0.05;
    
        
    %% Kvantile: 1%
    powerP = [0.005 : 0.001 : 0.015];
    powerV = [4.9772 7.5223 10.9198 17.3397 36.1779 372.758]; 
    powerPhi = [0 : 0.05 : 0.25];
    alphaVar = 0.01;
    
    disp(['Running ', num2str(nrSims(sims, length(powerP), length(powerV), length(powerPhi), length(dataLengths), length(tests))), ' simulations per quantile']);
    
    resultCell = cell(length(underlyingProcesses), length(dataLengths), 2);
    settingsCell = cell(3, 1);
    settingsCell{1,1} = underlyingProcesses;
    settingsCell{2,1} = dataLengths;
    settingsCell{3,1} = alphaVar;
    
    for i = 1:length(underlyingProcesses)
        underlyingProcess = underlyingProcesses{i};       
        for j=1:length(dataLengths)
            dataLength=dataLengths(j);
            [powerFunctionZ, settings] = savePower( tests, underlyingProcess, 'normal', alphaVar, alphaTest, lookback, dataLength, sims, powerV, powerPhi, powerP, runNr);
            resultCell{i, j, 1} = powerFunctionZ;
            resultCell{i, j, 2} = settings;
        end
    end
    
    storageCell{1, 1} = resultCell;
    storageCell{1, 2} = settingsCell;
    

    %% Kvantile: 5%
    powerP = [0.025 : 0.005 : 0.075];
    powerV = [2.561 2.8184 3.2175 3.9381 5.7888 30.3247]; 
    %powerPhi = [0 : 0.1 : 0.9];
    alphaVar = 0.05;
    
    resultCell = cell(length(underlyingProcesses), length(dataLengths), 2);
    settingsCell = cell(3, 1);
    settingsCell{1,1} = underlyingProcesses;
    settingsCell{2,1} = dataLengths;
    settingsCell{3,1} = alphaVar;
    
    for i = 1:length(underlyingProcesses)
        underlyingProcess = underlyingProcesses{i};       
        for j=1:length(dataLengths)
            dataLength=dataLengths(j);
            [powerFunctionZ, settings] = savePower( tests, underlyingProcess, 'normal', alphaVar, alphaTest, lookback, dataLength, sims, powerV, powerPhi, powerP, runNr);
            resultCell{i, j, 1} = powerFunctionZ;
            resultCell{i, j, 2} = settings;
        end
    end
    
    storageCell{2, 1} = resultCell;
    storageCell{2, 2} = settingsCell;
    
    
    %% Kvantile: 10%figure
    powerP = [0.05 : 0.01 : 0.15];
    powerV = [2.764 3.1562 3.8073 5.1002 8.9443 77.6785]; 
    %powerPhi = [0 : 0.1 : 0.9];
    alphaVar = 0.10;
    
    resultCell = cell(length(underlyingProcesses), length(dataLengths), 2);
    settingsCell = cell(3, 1);
    settingsCell{1,1} = underlyingProcesses;
    settingsCell{2,1} = dataLengths;
    settingsCell{3,1} = alphaVar;
    
    for i = 1:length(underlyingProcesses)
        underlyingProcess = underlyingProcesses{i};       
        for j=1:length(dataLengths)
            dataLength=dataLengths(j);
            [powerFunctionZ, settings] = savePower( tests, underlyingProcess, 'normal', alphaVar, alphaTest, lookback, dataLength, sims, powerV, powerPhi, powerP, runNr);
            resultCell{i, j, 1} = powerFunctionZ;
            resultCell{i, j, 2} = settings;
        end
    end
    
    storageCell{3, 1} = resultCell;
    storageCell{3, 2} = settingsCell;
    
    warning on
        
    %% Lagre resultat til fil
    savePath = [fileparts(which('getRunResults')) , '/storedRuns/'];
    savefile = [savePath, 'storageCell_Run_', num2str(rand()) ,'_', num2str(runNr), '.mat'];
    save(savefile, 'storageCell');
    
    %% Skriv ut at jobben er ferdig
    time = toc(start);
    disp(['Run # ', num2str(runNr), ' finished in: ', num2str(time), ' seconds']); 

    %% Avslutter Matlab (slik at vi ikke bruker undvendige ressurser p Solstorm
%    matlabpool close;
 %   exit;


end

