function [storageCell] = RunFunctionSubset( runNr )

    %% Bruk alle kjernene!    
    matlabpool;

    %% Legg alle filer i path som ligger under Matlab
    currentDir = fileparts(which('RunFunctionSubset'));
    addpath( genpath([currentDir, '/../../External Scripts']) );
    addpath( genpath([currentDir, '/../../MFEToolbox']) );
    addpath( genpath([currentDir, '/../../Under Progress']) );
    
    start = tic;
    
    %% Scripts og funksjoner vi nsker  kjre
    %  Bruk runNr til  spesifisere hva slags type jobb som skal kjres
    
    runNr = 10010 + runNr; % Unng overskriving, behold gamle filer    
            
    %warning off all;  
    
    RandStream.setDefaultStream(RandStream('mt19937ar', 'Seed', runNr ));
    
    spmd
        RandStream.setDefaultStream(RandStream('mt19937ar', 'Seed', runNr + labindex*1000 ));
    end
    
    
       %% Testene vi ble enige om  inkludere
    tests = {'testKupiec', 'testChristoffersenCC', 'testDQCC', 'testDQLogCC', 'testWeibullConCC', 'testWeibullDiscCC', 'testWeibullDiscHaasCC', 'testGeometricCC'};

    
    storageCell = cell(1, 2);  
    sims = 2000;
    
    varProcess = 'normal';
    underlyingProcesses = {'uniform', 'normal', 'studentt', 'garchnormal','garchstudentt'};
    lookback = 250;
    dataLengths = [1000];
    alphaTest = 0.05;
    
        
    %% Kvantile: 5%
    powerP = [0.025 : 0.005 : 0.075];
    powerV = [2.561 2.8184 3.2175 3.9381 5.7888 30.3247]; 
    powerPhi = [0 : 0.05 : 0.25];
    alphaVar = 0.05;
    
    resultCell = cell(length(underlyingProcesses), length(dataLengths), 5);
    settingsCell = cell(5, 1);
    settingsCell{1,1} = underlyingProcesses;
    settingsCell{2,1} = dataLengths;
    settingsCell{3,1} = alphaVar;
    settingsCell{4,1} = lookback;
    settingsCell{5,1} = alphaTest;
    
    for i = 1:length(underlyingProcesses)
        underlyingProcess = underlyingProcesses{i};       
        for j=1:length(dataLengths)
            dataLength=dataLengths(j);
            [powerFunctionZ, settings, statisticDistribution, notFeasibleRatio, notFeasibleThrownOutRatio] = savePower( tests, underlyingProcess, varProcess, alphaVar, alphaTest, lookback, dataLength, sims, powerV, powerPhi, powerP, runNr);
            resultCell{i, j, 1} = powerFunctionZ;
            resultCell{i, j, 2} = settings;
            resultCell{i, j, 3} = [];
            resultCell{i, j, 4} = notFeasibleRatio;
            resultCell{i, j, 5} = notFeasibleThrownOutRatio;
        end
    end
    
    storageCell{1, 1} = resultCell;
    storageCell{1, 2} = settingsCell;
    
    
   
    
    warning on
        
    %% Lagre resultat til fil
    savePath = [fileparts(which('getRunResults')) , '/storedRuns/'];
    savefile = [savePath, 'storageCell_Run_', num2str(rand()) ,'_', num2str(runNr), '.mat'];
    save(savefile, 'storageCell');
    
    %% Skriv ut at jobben er ferdig
    time = toc(start);
    disp(['Run # ', num2str(runNr), ' finished in: ', num2str(time), ' seconds']); 

    %% Avslutter Matlab (slik at vi ikke bruker undvendige ressurser p Solstorm
    matlabpool close;
    exit;


end

