function [statistics] = RunGarchNull( runNr )

    %% Bruk alle kjernene!    
    matlabpool;

        
    %% Legg alle filer i path som ligger under Matlab
    currentDir = fileparts(which('RunGarchNull'));
    addpath( genpath([currentDir, '/../../External Scripts']) );
    addpath( genpath([currentDir, '/../../MFEToolbox']) );
    addpath( genpath([currentDir, '/../../Under Progress']) );
    

    start = tic;
    
    %% Scripts og funksjoner vi nsker  kjre
    %  Bruk runNr til  spesifisere hva slags type jobb som skal kjres
    
    %runNr = runNr; % Unng overskriving, behold gamle filer    
            
    warning off all;  
    
    RandStream.setDefaultStream(RandStream('mt19937ar', 'Seed', runNr ));
    
    spmd
        RandStream.setDefaultStream(RandStream('mt19937ar', 'Seed', runNr + labindex*1000 ));
    end
    

    %% Tester vi nsker  kjre
    tests = {'testDQCC', 'testDQLogCC', 'testKupiec'};

    sims = 8*200;
    
    lookback = 250;
    varLevel = 0.05;
    datalength = 1000;
    garchParam = [0.01 0.20 0.79];
    
    statistics = zeros( numel(tests), sims);
        
    for j=1:numel(tests)
        
        tests{j}
        fh = str2func( tests{j} );
        distr = getDistribution(tests{j}, varLevel, datalength, 50000, 0);
    
        parfor i=1:sims
            
            tic;
            nextStatistic = NaN;
            i
            
            while isnan(nextStatistic)
                %[returns var] = generateSeries(0.04, 1500);
                %[returns var] = generateData('garchnormal','garchnormal',varLevel,datalength,lookback,0,[0.01 0.20 0.79]);
                [returns, var] = generateData('garchnormal', 'garchnormal', varLevel, datalength, lookback, 0, garchParam);
                nextStatistic = fh(returns, var, varLevel, distr, 0);
            end
            
            statistics(j, i) = nextStatistic;
            toc;

        end
    
    end
    
    storageCell = cell(6,1);
    storageCell{1} = statistics;
    storageCell{2} = tests;
    storageCell{3} = lookback;
    storageCell{4} = varLevel;
    storageCell{5} = datalength;
    storageCell{6} = garchParam;
    
    warning on
        
    %% Lagre resultat til fil
    savePath = [fileparts(which('getRunResults')) , '/storedGarchRuns/'];
    savefile = [savePath, 'storageCell_Run_', num2str(rand()) ,'_', num2str(runNr), '.mat'];
    save(savefile, 'storageCell');
    
    %% Skriv ut at jobben er ferdig
    time = toc(start);
    disp(['Run # ', num2str(runNr), ' finished in: ', num2str(time), ' seconds']); 

    %% Avslutter Matlab (slik at vi ikke bruker undvendige ressurser p Solstorm
    matlabpool close;
    exit;


end

