function [ power, statisticDistribution, notFeasibleRatio, notFeasibleThrownOutRatio ] = getPow(functionName, underlyingProcess, VaRProcess, alphaVaR, v, phi, p, dataLength, alphaTest, distribution, lookback, sims, explicitParameters)

    if(length(phi) > 1)
        garchParameters = phi;
    else
        garchParameters = [0.01, phi, 0.99-phi];
    end
    
    numberOfRejections = 0;
    statisticDistribution = zeros(sims, 1);
    
    notFeasible = 0;
    notFeasibleThrownOut = 0;
    
    fh = str2func(functionName);    
    
    if(strcmp(underlyingProcess, 'uniform') || strcmp(VaRProcess, 'uniform'))
    
        parfor i = 1:sims
            
            testStatistic = NaN;
            
            while(isnan(testStatistic))
                [returns, var] = generateSeries(p, dataLength);
                [testStatistic, notFeasibleThrownOutTemp] = fh(returns, var, alphaVaR, [], 1);
                notFeasible = notFeasible + isnan(testStatistic);
                notFeasibleThrownOut = notFeasibleThrownOut + notFeasibleThrownOutTemp;
            end
            
            statisticDistribution(i) = testStatistic;
            
            if FindP(testStatistic, distribution) < alphaTest
                numberOfRejections = numberOfRejections + 1;
            end
            
        end
        
    else
            
        parfor i = 1:sims
            
            testStatistic = NaN;
            
            while(isnan(testStatistic))
                [returns, var] = generateData(underlyingProcess, VaRProcess, alphaVaR, dataLength, lookback, v, garchParameters);
                [testStatistic, notFeasibleThrownOutTemp] = fh(returns, var, alphaVaR, [], 1);
                notFeasible = notFeasible + isnan(testStatistic);
                notFeasibleThrownOut = notFeasibleThrownOut + notFeasibleThrownOutTemp;
            end
            
            statisticDistribution(i) = testStatistic;
            
            if FindP(testStatistic, distribution) < alphaTest
                numberOfRejections = numberOfRejections + 1;
            end
            
        end
        
    end
    
    power = numberOfRejections / sims;  
    notFeasibleRatio = notFeasible / sims;
    notFeasibleThrownOutRatio = notFeasibleThrownOut / sims;
    
end