function [ powerFunctionZ, sims, powerV, powerPhi, powerP, statisticDistribution, notFeasibleRatio, notFeasibleThrownOutRatio] = getPowerFunction( testName, underlyingProcess, varProcess, alphaVar, alphaTest, lookback, dataLength, storageCells )
%GETPOWERFUNCTION Summary of this function goes here
%   Detailed explanation goes here

% functionName, underlyingProcess, VaRProcess, alpha, alphaTest, lookback, dataLength, sims, powerP, powerV, powerPhi, powerFunctionZ
%% sims, powerV, powerPhi, powerP

sims = 0;
powerV = NaN;
powerPhi = NaN;
powerP = NaN;
powerFunctionZ = NaN;
parametersSet = 0;
statisticDistribution = NaN;
notFeasibleRatio = NaN;
notFeasibleThrownOutRatio = NaN;

for i=1:length(storageCells)
    
    varLevelIndex = NaN;
    
    %% Find correct VaR level
    for j=1:size(storageCells{i}, 1)
        if( storageCells{i}{j,2}{3} == alphaVar )
            varLevelIndex = j;
            break;
        end
    end
    
    if( isnan(varLevelIndex) )
        continue;
    end
    
    underlyingIndex = find( strcmp( storageCells{i}{j,2}{1}, underlyingProcess) );
    lengthIndex = find( storageCells{i}{j,2}{2} == dataLength );
    
    if( isempty(underlyingIndex) || isempty(lengthIndex) )
        continue;
    end
        
    
    settingsTemp = storageCells{i}{j,1}{underlyingIndex, lengthIndex, 2};
    
    if( settingsTemp(1).lookback ~= lookback || settingsTemp(1).alphaTest ~= alphaTest || ~strcmp(settingsTemp(1).VaRProcess, varProcess))
        %warning('Lookback, alphaTest or varProccess not equal');
        continue;
    end
    
    
    if( ~parametersSet)
        powerV = settingsTemp(1).powerV;
        powerPhi = settingsTemp(1).powerPhi;
        powerP = settingsTemp(1).powerP;
    elseif(~isequal(settingsTemp(1).powerV, powerV) || ~isequal(settingsTemp(1).powerPhi, powerPhi) || ~isequal(settingsTemp(1).powerP, powerP))
        warning('Power parameters dont agree');
        continue;
    end

    functionIndex = NaN;
    
    for k=1:length(settingsTemp)
        if(strcmp(settingsTemp(k).functionNames, testName))
            functionIndex = k;
            break;
        end
    end
    
    if(isnan(functionIndex))
        warning('Function index not found');
        continue;
    end
    
    simsTemp = settingsTemp(1).sims;
    sims = sims + simsTemp;
    
    if(~parametersSet )
        powerFunctionZ = storageCells{i}{j,1}{underlyingIndex, lengthIndex, 1}(1, functionIndex, :, :, :)*simsTemp;
        
        notFeasibleRatio = storageCells{i}{j,1}{underlyingIndex, lengthIndex, 4}(1, functionIndex, :, :, :)*simsTemp;
        notFeasibleThrownOutRatio = storageCells{i}{j,1}{underlyingIndex, lengthIndex, 4}(1, functionIndex, :, :, :)*simsTemp;
        
        %% Hvis vi trenger distribusjoner, s m dette fikses
        % statisticDistribution = storageCells{i}{j,1}{underlyingIndex, lengthIndex, 3}(1, functionIndex, :, :, :, :);
        
    else
        powerFunctionZ = powerFunctionZ + storageCells{i}{j,1}{underlyingIndex, lengthIndex, 1}(1, functionIndex, :, :, :)*simsTemp;
        
        notFeasibleRatio = notFeasibleRatio + storageCells{i}{j,1}{underlyingIndex, lengthIndex, 4}(1, functionIndex, :, :, :)*simsTemp;
        notFeasibleThrownOutRatio = notFeasibleThrownOutRatio + storageCells{i}{j,1}{underlyingIndex, lengthIndex, 4}(1, functionIndex, :, :, :)*simsTemp;
        
        %% Hvis vi trenger distribusjoner, s m dette fikses
        % statisticDistribution = cat(6, statisticDistribution, storageCells{i}{j,1}{underlyingIndex, lengthIndex, 3}(1, functionIndex, :, :, :, :));
    end
    
    parametersSet = 1;

end

powerFunctionZ = powerFunctionZ / sims;
notFeasibleRatio = notFeasibleRatio ./ (sims + notFeasibleRatio);
notFeasibleThrownOutRatio = notFeasibleThrownOutRatio ./ (sims + notFeasibleThrownOutRatio);

powerFunctionZ = shiftdim(powerFunctionZ, 2);
notFeasibleRatio = shiftdim(notFeasibleRatio, 2);
notFeasibleThrownOutRatio = shiftdim(notFeasibleThrownOutRatio, 2);
statisticDistribution = shiftdim(statisticDistribution, 2);

end


