function [ output_ars ] = plotAllPValues(functionNames, underlyingProcess, VaRProcess, alphaVaR, alphaTest, lookback, dataLength, sims, powerV, powerPhi)
%GETALLPVALUES Plots the histogram of all the p-values given by test and
%alphaVaR
%   functionNames: Cell of strings, e.g. {'testChristoffersen',
%   'testKupiec'}
%   underlyingProcess: String input to generateData
%   VaRProcess: String input to generateData ('normal' is the only option
%   so far)
%   alphaVaR: Table of VaR-levels, e.g. [0.01 0.05 0.1]
%   alphaTest: Double Test significance level
%   lookback: Integer
%   dataLength: Length of the return/VaR series
%   sims: # simulations per point of the power function
%   powerV: Integer degrees of freedom for the t-distribution
%   powerPhi: Double garch parameter for the underlying process


    for i = 1:length(functionNames)
        functionName = functionNames{i};
        for j = 1:length(alphaVaR)
            distribution = getDistribution(functionName, alphaVaR(j), dataLength - lookback, 50000, 0);
            pVal = getPValues(functionName, underlyingProcess, VaRProcess, alphaVaR(j), powerV, powerPhi, dataLength, distribution, lookback, sims);
            
            figure;
            hist(pVal);
            title([functionName, ' alphaVaR = ', num2str(alphaVaR(j))]);

            disp(functionName);
        end
    end
    
    output_args = 1;
end

