function [ ] = plotPower( functionName, underlyingProcess, VaRProcess, alpha, alphaTest, lookback, dataLength, sims, powerP, powerV, powerPhi, powerFunctionZ)
    
        if( length(alpha) > 1)
            
            for i=1:length(alpha)
                plotPower( functionName, underlyingProcess, VaRProcess, alpha(i), alphaTest, lookback, dataLength, sims)
            end
            
            return;
                       
        elseif( length(dataLength) > 1)
            
            for i=1:length(dataLength)
                plotPower( functionName, underlyingProcess, VaRProcess, alpha, alphaTest, lookback, dataLength(i), sims)
            end
            
            return;
            
        end
        
        
        if( nargin < 12)
            if( nargin > 7 )
                [powerFunctionZ, sims, powerV, powerPhi, powerP] = getPowerFunction(functionName, underlyingProcess, VaRProcess, alpha, alphaTest, lookback, dataLength, sims);
            else
                [powerFunctionZ, sims, powerV, powerPhi, powerP] = getPowerFunction(functionName, underlyingProcess, VaRProcess, alpha, alphaTest, lookback, dataLength, getRunResults());
            end
        end
        
        if(sims == 0)
            warning('No simulations for given configuration');
            return;
        end

        titleName = [functionName, ' ', underlyingProcess, ' alphaVaR = ', num2str(alpha), ' lookback = ', num2str(lookback), ' datalength = ' , num2str(dataLength), ' sims = ', num2str(sims)];
        figure('name', titleName, 'numbertitle', 'off');

        %Setting up the correct plot
        if(length(powerP) > 1)
            line(powerP, alphaTest*ones(length(powerP)), 'color', 'red', 'LineStyle', ':');
            hold on;
            plot(powerP, powerFunctionZ');
            set(gca, 'YLim', [0 1], 'XLim' , [powerP(1) powerP(length(powerP))]);
            title(titleName);
            ylabel('Rejection frequency');
            xlabel('p1');        
        elseif(length(powerPhi) == 1 && length(powerV) == 1)
            line([1:10], powerFunctionZ*ones(10, 1), 'color', 'black');
            hold on;
            line([1:10], alphaTest*ones(10, 1), 'color', 'red', 'LineStyle', ':');
            set(gca,'YLim',[0 1]);
            set(gca,'xtick',[]); 
            title(titleName);
            ylabel('Rejection frequency');        
        elseif(length(powerPhi) == 1)
            line(powerV, alphaTest*ones(length(powerV)), 'color', 'red','LineStyle', ':');
            hold on;
            plot(powerV, powerFunctionZ);
            title(titleName);
            set(gca, 'XTick', round(powerV));
            set(gca, 'XScale', 'log');
            set(gca,'XLim', [round(powerV(1)) round(powerV(length(powerV)))], 'YLim',[0 1]);
            ylabel('Rejection frequency');
            xlabel('v');
        elseif(length(powerV) == 1)
            powerFZ = [];
            for i = 1:length(powerFunctionZ)
                powerFZ = [powerFZ; powerFunctionZ(:,:,i)];
            end
            
            line(powerPhi, alphaTest*ones(length(powerPhi)), 'color', 'red', 'LineStyle', ':');
            hold on;
            plot(powerPhi, powerFZ);
            title(titleName);
            set(gca,'XLim', [powerPhi(1) powerPhi(length(powerPhi))],'XTick',powerPhi,'YLim',[0 1]);
            ylabel('Rejection frequency');
            xlabel('arch-term');
        else
            powerFunctionY = [];
            powerFunctionX = [];
            powerFZ = [];
            for i = 1:size(powerPhi,2)
               powerFunctionY = [powerFunctionY; powerV];
            end

            for i = 1:size(powerV,2)
               powerFunctionX = [powerFunctionX powerPhi'];
            end
            for i = 1:length(powerFunctionZ)
                powerFZ = [powerFZ; powerFunctionZ(:,:,i)];
            end
            
            powerFunctionZ = powerFZ;

            surfl(powerFunctionX, powerFunctionY, powerFunctionZ);
            shading interp;
            colormap(pink);
            set(gca, 'YScale', 'log','ZLim',[0 1]);
            set(gca, 'YLim', [round(powerV(1)) round(powerV(length(powerV)))]);
            set(gca, 'YTick', round(powerV));

            title(titleName);
            xlabel('arch-term');
            ylabel('v');
            zlabel('Rejection frequency');
        end
        
        
end

