function [figureHandles] = plotPower2( functionName, underlyingProcess, VaRProcess, alpha, alphaTest, lookback, dataLength, savePlot, runResults, dataStructure)
    
        if(nargin < 8)
            savePlot = 0;
        end

        % Get run results if it is not defined
        if(nargin < 9)
            figureHandles = plotPower2( functionName, underlyingProcess, VaRProcess, alpha, alphaTest, lookback, dataLength, savePlot, getRunResults());
        elseif(nargin > 9)
            
            xAxis = dataStructure.xAxis;
            yAxis = dataStructure.yAxis;
            axisColor = dataStructure.axisColor;                        
            plot(xAxis, yAxis, axisColor);
               
        else
            
            figureHandles = struct;
            
            % For each function name
            if(~isstr(functionName))
                
                for i=1:numel(functionName)
                    fH = plotPower2( functionName{i}, underlyingProcess, VaRProcess, alpha, alphaTest, lookback, dataLength, savePlot, runResults);
                    figureHandles = setfield(figureHandles, functionName{i}, fH);
                end
                
                return;
                
            end
        
            % For each underlying process
            if(~isstr(underlyingProcess))

                for i=1:numel(underlyingProcess)
                    fH = plotPower2( functionName, underlyingProcess{i}, VaRProcess, alpha, alphaTest, lookback, dataLength, savePlot, runResults);
                    figureHandles = setfield(figureHandles, underlyingProcess{i}, fH);
                end
                
                return;
                
            end
            
            % For each alpha
            if(numel(alpha) > 1)
                
                for i=1:numel(alpha)
                    fH = plotPower2( functionName, underlyingProcess, VaRProcess, alpha(i), alphaTest, lookback, dataLength, savePlot, runResults);
                    figureHandles = setfield(figureHandles, ['alpha', num2str(alpha(i)*100)], fH);
                end
                
                return;
                
            end
            
            % For each lookback
            if(numel(lookback) > 1)
                
                for i=1:numel(lookback)
                    fH = plotPower2( functionName, underlyingProcess, VaRProcess, alpha, alphaTest, lookback(i), dataLength, savePlot, runResults);
                    figureHandles = setfield(figureHandles, ['lookback', num2str(lookback(i))], fH);
                end
                
                return;
                
            end
            
            % For each data length if garch
            if(numel(dataLength) > 1 && numel(underlyingProcess) > 5 && strcmp(underlyingProcess(1:5), 'garch'))
                
                for i=1:numel(dataLength)
                    fH = plotPower2( functionName, underlyingProcess, VaRProcess, alpha, alphaTest, lookback, dataLength(i), savePlot, runResults);
                    figureHandles = setfield(figureHandles, ['dataLength', num2str(dataLength(i))], fH);
                end
                
                return;
                
            end
            
            colorMap = {'b', 'g', 'r', 'c', 'm', 'y', 'k', 'w'};
            titleName = [functionName, ' ', underlyingProcess, ' alphaVaR = ', num2str(alpha), ' lookback = ', num2str(lookback), ' datalength = ' , num2str(dataLength)];
            figureHandles = figure('name', titleName, 'numbertitle', 'off');
            
            hold on;            
            dataStructure = struct;
            labelNames = {};
            
            for i=1:length(dataLength)
                
                [powerFunctionZ, sims, powerV, powerPhi, powerP] = getPowerFunction(functionName, underlyingProcess, VaRProcess, alpha, alphaTest, lookback, dataLength(i),  runResults);
            
                                
                if(length(powerPhi) > 1)
                    dataStructure.xAxis = powerPhi;                                        
                    for j=1:length(powerV)                    
                        dataStructure.yAxis = shiftdim(powerFunctionZ(:, j, :));
                        dataStructure.axisColor = colorMap{ j };
                        plotPower2( functionName, underlyingProcess, VaRProcess, alpha, alphaTest, lookback, dataLength(i), savePlot, runResults, dataStructure);
                        labelNames{j} = ['v=',num2str(powerV(j))];
                    end
                    xlabel('Phi');
                elseif(length(powerV) > 1)
                    dataStructure.xAxis = powerV;
                    dataStructure.yAxis = powerFunctionZ;
                    dataStructure.axisColor = colorMap{ i };
                    plotPower2( functionName, underlyingProcess, VaRProcess, alpha, alphaTest, lookback, dataLength(i), savePlot, runResults, dataStructure);
                    labelNames{i} = ['N=',num2str(dataLength(i))];
                    xlabel('Degrees of freedom (v)');
                elseif(length(powerP) > 1)
                    dataStructure.xAxis = powerP;
                    dataStructure.yAxis = powerFunctionZ;
                    dataStructure.axisColor = colorMap{ i };
                    plotPower2( functionName, underlyingProcess, VaRProcess, alpha, alphaTest, lookback, dataLength(i), savePlot, runResults, dataStructure);
                    labelNames{i} = ['N=',num2str(dataLength(i))];
                    xlabel('P');
                end

            end
            
            legend( labelNames );
            ylabel('Rejection rate');
            line(dataStructure.xAxis, alphaTest*ones(length(dataStructure.xAxis), 1), 'color', 'red', 'LineStyle', ':');
            set(gca,'YLim',[0 1]);
            title( titleName );
            
            if(savePlot)
               
                
                           
                name = [functionName, '.', underlyingProcess, '.', num2str(alpha*100), '.', num2str(lookback)];
                
                if(length(dataLength) == 1)
                    name = [name, '.', num2str(dataLength)];
                else
                    name = [name, '.all'];
                end
                
                
                savePlots(figureHandles, [name, '.']);
                close(figureHandles);                
                
            end
            
            
        end
        
        
end

