function [figureHandles] = plotPower3( functionName, underlyingProcess, VaRProcess, alpha, alphaTest, lookback, dataLength, savePlot, runResults, dataStructure)
    
        if(nargin < 8)
            savePlot = 0;
        end

        % Get run results if it is not defined
        if(nargin < 9)
            figureHandles = plotPower3( functionName, underlyingProcess, VaRProcess, alpha, alphaTest, lookback, dataLength, savePlot, getRunResults());
        elseif(nargin > 9 && ~isfield(dataStructure, 'df'))
            
            xAxis = dataStructure.xAxis;
            yAxis = dataStructure.yAxis;
            axisColor = dataStructure.axisColor;                        
            plot(xAxis, yAxis, axisColor);
               
        else
            
            figureHandles = struct;
            
        
            % For each underlying process
            if(~isstr(underlyingProcess))

                for i=1:numel(underlyingProcess)
                    fH = plotPower3( functionName, underlyingProcess{i}, VaRProcess, alpha, alphaTest, lookback, dataLength, savePlot, runResults);
                    figureHandles = setfield(figureHandles, underlyingProcess{i}, fH);
                end
                
                return;
                
            end
            
            % For each alpha
            if(numel(alpha) > 1)
                
                for i=1:numel(alpha)
                    fH = plotPower3( functionName, underlyingProcess, VaRProcess, alpha(i), alphaTest, lookback, dataLength, savePlot, runResults);
                    figureHandles = setfield(figureHandles, ['alpha', num2str(alpha(i)*100)], fH);
                end
                
                return;
                
            end
            
            % For each lookback
            if(numel(lookback) > 1)
                
                for i=1:numel(lookback)
                    fH = plotPower3( functionName, underlyingProcess, VaRProcess, alpha, alphaTest, lookback(i), dataLength, savePlot, runResults);
                    figureHandles = setfield(figureHandles, ['lookback', num2str(lookback(i))], fH);
                end
                
                return;
                
            end
            
            % For each data length if garch
            if(numel(dataLength) > 1)
                
                for i=1:numel(dataLength)
                    fH = plotPower3( functionName, underlyingProcess, VaRProcess, alpha, alphaTest, lookback, dataLength(i), savePlot, runResults);
                    figureHandles = setfield(figureHandles, ['dataLength', num2str(dataLength(i))], fH);
                end
                
                return;
                
            end
            
            if(numel(underlyingProcess) > 5 && strcmp(underlyingProcess(1:5), 'garch') && nargin < 10)
                
                [~, ~, V, ~, ~] = getPowerFunction('testKupiec', underlyingProcess, VaRProcess, alpha, alphaTest, lookback, dataLength,  runResults);
                
                for i=1:length(V)
                    dataStructure = struct('df', i, 'dfName', V(i));
                    plotPower3( functionName, underlyingProcess, VaRProcess, alpha, alphaTest, lookback, dataLength, savePlot, runResults, dataStructure);
                end
                
                return;
                
            end
            
            colorMap = {'b', 'g', 'r', 'c', 'm', 'y', 'k', 'b:', 'g:', 'r:', 'c:', 'm:', 'y:', 'k:'};
            titleName = [underlyingProcess, ' alphaVaR = ', num2str(alpha), ' lookback = ', num2str(lookback), ' datalength = ' , num2str(dataLength)];
            
            
            
            if(nargin > 9)
                df = dataStructure.df;
                dfName = dataStructure.dfName;
                titleName = [titleName, ' v=', num2str(dfName)];
            end
            
            
            figureHandles = figure('name', titleName, 'numbertitle', 'off');
            
            hold on;            
            dataStructure = struct;
            labelNames = {};
            
            minSims = Inf;
            maxSims = -Inf;
            
            dropped = 0;
                       
            for i=1:length(functionName)
                
                if(isstr(functionName))
                    fName = functionName;
                else
                    fName = functionName{i};
                end
                
                
                [powerFunctionZ, sims, V, Phi, P] = getPowerFunction(fName, underlyingProcess, VaRProcess, alpha, alphaTest, lookback, dataLength,  runResults);
                
                % No simulations
                if(sims == 0)
                    dropped = dropped + 1;
                    continue;
                end
                
                minSims = min(minSims, sims);
                maxSims = max(maxSims, sims);
                                
                if(length(Phi) > 1)
                    
                     dataStructure.xAxis = Phi;                                        
                                      
                     dataStructure.yAxis = shiftdim(powerFunctionZ(:, df, :));
                     dataStructure.axisColor = colorMap{ i };
                     plotPower3( fName, underlyingProcess, VaRProcess, alpha, alphaTest, lookback, dataLength, savePlot, runResults, dataStructure);
                     labelNames{i - dropped} = fName;
                    
                    xlabel('Phi');
                elseif(length(V) > 1)
                    dataStructure.xAxis = V;
                    dataStructure.yAxis = powerFunctionZ;
                    dataStructure.axisColor = colorMap{ i };
                    plotPower3( fName, underlyingProcess, VaRProcess, alpha, alphaTest, lookback, dataLength, savePlot, runResults, dataStructure);
                    labelNames{i - dropped} = fName;
                    xlabel('Degrees of freedom (v)');
                elseif(length(P) > 1)
                    dataStructure.xAxis = P;
                    dataStructure.yAxis = powerFunctionZ;
                    dataStructure.axisColor = colorMap{ i };
                    plotPower3( fName, underlyingProcess, VaRProcess, alpha, alphaTest, lookback, dataLength, savePlot, runResults, dataStructure);
                    labelNames{i - dropped} = fName;
                    xlabel('P');
                end
                
                 if(isstr(functionName))
                    break;
                end

            end
            
            legend( labelNames );
            ylabel('Rejection rate');
            line(dataStructure.xAxis, alphaTest*ones(length(dataStructure.xAxis), 1), 'color', 'red', 'LineStyle', ':');
            set(gca,'YLim',[0 1]);
            title( [titleName, ' sims=[', num2str(minSims), ',', num2str(maxSims), ']'] );
            
            if(savePlot)
                               
                           
                name = [underlyingProcess, '.', num2str(alpha*100), '.', num2str(lookback)];
                
                if(length(dataLength) == 1)
                    name = [name, '.', num2str(dataLength)];
                else
                    name = [name, '.all'];
                end
                
                if(nargin > 9)
                    name = [name, '.', num2str(V(df))]; 
                else
                    name = [name, '.na']; 
                end
                
                
                savePlots(figureHandles, [name, '.']);
                close(figureHandles);                
                
            end
            
            
        end
        
        
end

