function [ output_args ] = savePower( functionNames, underlyingProcess, VaRProcess, alphaVaR, alphaTest, lookback, dataLength, sims, powerV, powerPhi, powerP, id)
%SAVEPOWER Saves (to file) the power of the tests given the underlying process and
%VaR estimation procedure
%   functionNames: Cell of strings, e.g. {'testChristoffersen',
%   'testKupiec'}
%   underlyingProcess: String input to generateData. If 'uniform' it
%   generates data from the breach series
%   VaRProcess: String input to generateData ('normal' is the only option
%   so far)
%   alphaVaR: Table of VaR-levels, e.g. [0.01 0.05 0.1]
%   alphaTest: Double Test significance level
%   lookback: Integer
%   dataLength: Length of the return/VaR series
%   simulations: # simulations per point of the power function
%   powerV: Table of degrees of freedoms for the underlying process, e.g.
%   [3:1:10]
%   powerPhi: Table of garch parameters for the underlying process, e.g.
%   [0:0.1:1]
%   powerP: Table of alternative hypothesis for the uniform distribution
%   (breach probability) e.g. [0:0.01:1]
%   id: Integer to set some identification at the end of the filename

if(strcmp(underlyingProcess, 'uniform') || strcmp(VaRProcess, 'uniform'))
    powerFunctionZ = zeros(length(powerP), 1); % power
    for l = 1:length(alphaVaR)
        for j = 1:length(functionNames)
            powerFunctionX = [];
            powerFunctionY = [];
            functionName = functionNames{j};
            distribution = getDistribution(functionName, alphaVaR(l), dataLength, 50000, 0);
            
            showString = [underlyingProcess, ' ', VaRProcess, ' ', num2str(alphaVaR(l)), ' ', num2str(dataLength), ' ', num2str(lookback)];
            disp(showString);
            
            for i = 1:length(powerP)
                %Test for varying parameters, p
                %showString = [underlyingProcess, ' ', VaRProcess, ' ', num2str(alphaVaR(l)), ' ', num2str(dataLength), ' ', num2str(lookback), ' ', num2str(powerP(i))];
                %disp(showString);
                powerFunctionZ(i) = getPow(functionName, underlyingProcess, VaRProcess, alphaVaR(l), 0, 0, powerP(i), dataLength, alphaTest, distribution,lookback, sims);
            end

            savefile = [fileparts(which('savePower')),'/powerFunctions/', functionName, '_', underlyingProcess, '_', VaRProcess, '_', num2str(alphaVaR(l)), '_', num2str(alphaTest), '_', num2str(id), '.mat'];
            alpha = alphaVaR(l);
            save(savefile, 'powerFunctionZ', 'powerP', 'functionName', 'underlyingProcess', 'VaRProcess', 'alpha', 'alphaTest', 'lookback', 'dataLength', 'sims');
        end
    end
else
    powerFunctionZ = zeros(length(powerV), length(powerPhi)); % power
    for l = 1:length(alphaVaR)
        for j = 1:size(functionNames, 2)
        	powerFunctionX = [];
        	powerFunctionY = [];
            functionName = functionNames{j};
            distribution = getDistribution(functionName, alphaVaR(l), dataLength, 50000, 0);
            
            for i = 1:size(powerV, 2)
                for k = 1:size(powerPhi, 2)
                    %Test for varying parameters, v and phi
                    showString = [underlyingProcess, ' ', VaRProcess, ' ', num2str(alphaVaR(l)), ' ', num2str(dataLength), ' ', num2str(lookback), ' ', num2str(powerV(i)), ' ', num2str(powerPhi(k))];
                    disp(showString);
                    powerFunctionZ(i, k) = getPow(functionName, underlyingProcess, VaRProcess, alphaVaR(l), powerV(i), powerPhi(k), 0, dataLength, alphaTest, distribution,lookback, sims);
                end
            end
            
            savefile = [fileparts(which('savePower')),'/powerFunctions/', functionName, '_', underlyingProcess, '_', VaRProcess, '_', num2str(alphaVaR(l)), '_', num2str(alphaTest), '_', num2str(id), '.mat'];
            alpha = alphaVaR(l);
            save(savefile, 'powerFunctionZ', 'powerV', 'powerPhi', 'functionName', 'underlyingProcess', 'VaRProcess', 'alpha', 'alphaTest', 'lookback', 'dataLength', 'sims');
        end
    end
end


output_args = 1;

end

