function [ outputCell ] = getFeasibilityRatioTable(getRunResults, underlying, varLevel, lookback, powerPFixed, powerPhiFixed, powerVFixed, datalengthFixed)

% Set *Fixed parameter to 0 to iterate over this value
% Otherwise, set it to a index corresponding to the fixed value you want to
% hold constant
    

% samples
dataLengths = [100 250 500 750 1000 1250 1500];

% tests
tests = {'testKupiec', 'testChristoffersenCC', 'testDQCC', 'testDQLogCC', 'testWeibullConCC', 'testWeibullDiscCC', 'testWeibullDiscHaasCC', 'testGeometricCC'};
testNames = {'PF', 'Markov', 'DQ', 'DQLogit', 'Cont', 'Disc', 'Haas', 'Geo'};

[ ~, ~, powerV, powerPhi, powerP, ~, notFeasibleRatio, notFeasibleThrownOutRatio] = getPowerFunction( 'testKupiec', underlying, 'normal', varLevel, 0.05, 1000, 1000, getRunResults );

dimOutput = (numel(powerV) > 1) + (numel(powerPhi) > 1) + (numel(powerP) > 1) + 1;
dimInput = (powerPhiFixed > 0) + (powerVFixed > 0) + (powerPFixed > 0) + (datalengthFixed > 0);

if dimOutput - dimInput ~= 1
    warning('Only 2D table allowed. You have to fix input dimension');
    return;
end

xLength = numel(tests) + 1;
yLength = ((numel(powerV) > 1) - (powerVFixed > 0)) * numel(powerV) + ...
          ((numel(powerPhi) > 1) - (powerPhiFixed > 0)) * numel(powerPhi) + ...
          ((numel(powerP) > 1) - (powerPFixed > 0)) * numel(powerP) + ...
          (1 - (datalengthFixed > 0)) * numel(dataLengths) + 1;

outputCell = cell(yLength, xLength);

for x=1:numel(tests)
    outputCell(1, x+1) = {testNames{x}};
end

UL = ['underlying=', underlying, ', varLevel=', num2str(varLevel), ', lookback=', num2str(lookback)];

if numel(powerP) > 1
    if powerPFixed > 0
        UL = [UL, ', P=', num2str(powerP(powerPFixed))];
    else
        UL = [UL, ', P=X'];
    end
end

if numel(powerPhi) > 1
    if powerPhiFixed > 0
        UL = [UL, ', Phi=', num2str(powerPhi(powerPhiFixed))];
    else
        UL = [UL, ', Phi=X'];
    end
end

if numel(powerV) > 1
    if powerVFixed > 0
        UL = [UL, ', V=', num2str(powerV(powerVFixed))];
    else
        UL = [UL, ', V=X'];
    end
end

if numel(dataLengths) > 1
    if datalengthFixed > 0
        UL = [UL, ', L=', num2str(dataLengths(datalengthFixed))];
    else
        UL = [UL, ', L=X'];
    end
end

outputCell(1, 1) = {UL};

for x=1:numel(tests)
   
    test = tests{x};   
      
        if datalengthFixed == 0
            
            for l=1:numel(dataLengths)
               
                [ ~, ~, powerV, powerPhi, powerP, ~, notFeasibleRatio, ~] = getPowerFunction( test, underlying, 'normal', varLevel, 0.05, lookback, dataLengths(l), getRunResults );
                
                if strcmp(underlying, 'uniform')
                    notFeasibleRatio = notFeasibleRatio(powerPFixed);
                elseif strcmp(underlying, 'studentt')
                    notFeasibleRatio = notFeasibleRatio(1, powerVFixed);
                elseif strcmp(underlying, 'garchstudentt')
                    notFeasibleRatio = notFeasibleRatio(1, powerPhiFixed, powerVFixed);
                else
                    warning('Not applicable');
                    return;
                end
                
                outputCell(l+1,x+1) = {1-notFeasibleRatio};
                outputCell(l+1,1) = {dataLengths(l)};
                
            end
            
            
        else
            
            for y=1:(yLength - 1)
            
                [ ~, ~, powerV, powerPhi, powerP, ~, notFeasibleRatio, ~] = getPowerFunction( test, underlying, 'normal', varLevel, 0.05, lookback, dataLengths(datalengthFixed), getRunResults );
                
                if strcmp(underlying, 'uniform')
                    notFeasibleRatio = notFeasibleRatio(y);
                    outputCell(y+1,1) = {powerP(y)};
                elseif strcmp(underlying, 'studentt')
                    notFeasibleRatio = notFeasibleRatio(1, y);
                    outputCell(y+1,1) = {powerV(y)};
                elseif strcmp(underlying, 'garchstudentt')
                    
                    Phi = powerPhiFixed;
                    V = powerVFixed;
                    
                    if powerPhiFixed == 0
                        outputCell(y+1,1) = {powerPhi(y)};
                        Phi = y;
                    else
                        outputCell(y+1,1) = {powerV(y)};
                        V = y;
                    end                        
                      
                    notFeasibleRatio = notFeasibleRatio(1, Phi, V);
                    
                else
                    warning('Not applicable');
                    return;
                end      
                
                outputCell(y+1,x+1) = {1-notFeasibleRatio};
            
            end
                
        end    
    
    
end

%latexFormat = getLatexTable( outputCell(2:end, 2:end), outputCell(1:end, 1), outputCell(1, 1:end)
latexOutput = outputCell;
latexOutput(1,1) = {''};

% Make left col string
for i=2:yLength
    latexOutput{i, 1} = num2str(latexOutput{i, 1});
end

getLatexTable( cell2mat( latexOutput(2:end, 2:end) ), latexOutput(2:end, 1), latexOutput(1, 1:end), [], UL, 'labelXX', UL);

      
end

