function [ returns, varSeries, zSeries, sigmat] = generateData(underlyingProcess, varProcess, alphaVaR, dataLength, lookback, V, garchPar)
%GENERATEDATA is a function which produces return- and var series
%underlyingProcess: 'normal','studentt', 'garchnormal', 'garchstudentt'
%varProcess: 'normal', 'hs'
%dataLength: length og the data series that will be returned (VaR and
%returns). NB! will not be cut off!
%V: Degrees of freedom if studentt is selected as varProcess
%garchPar: Garch parameter if garchstudentt is selected as varProcess
%[constant, archTerm, garchTerm]. If ngarch is selected use the following
%format [delta, theta, beta, alpha, omega]


if(strcmp(underlyingProcess,'normal'))
    returns = generateNormalReturns(0,1,dataLength, lookback); 
elseif(strcmp(underlyingProcess,'studentt'))
    returns = generateStudTReturns(0,1,V,dataLength, lookback); 
elseif(strcmp(underlyingProcess,'garchnormal'))
    if(length(garchPar)~=3)
        error('generateData: garchPar should be [constant, archTerm, garchTerm]')
    end
    [returns sigmat] = generateGarchReturns(dataLength, lookback,[garchPar(1) garchPar(2) garchPar(3)],1,0,1,'NORMAL');
elseif(strcmp(underlyingProcess,'garchstudentt'))
	if(length(garchPar)~=3)
        error('generateData: garchPar should be [constant, archTerm, garchTerm]')
	end
    [returns sigmat]= generateGarchReturns(dataLength, lookback,[garchPar(1) garchPar(2) garchPar(3) V],1,0,1,'STUDENTST');
    sigmat = sigmat(lookback+1:length(sigmat));
elseif(strcmp(underlyingProcess,'ngarchstudentt'))
	if(length(garchPar)~=4)
        error('generateData: garchPar should be [theta, beta, alpha, omega]')
	end
    returns = generateNGARCHt(dataLength, lookback, V,garchPar(1),garchPar(2),garchPar(3),garchPar(4));
else
    error('generateData: underlyingprocess undefined')
end



if(strcmp(varProcess,'normal'))
    [varSeries, ~, zSeries0] = generateNormalVaR( returns, alphaVaR, lookback );
elseif(strcmp(varProcess,'hs'))
    [varSeries, ~, zSeries0] = generateHistoricalVaR( returns, alphaVaR, lookback );
elseif(strcmp(varProcess,'garchnormal'))
    [varSeries, ~, zSeries0] = generateNormalGarchVaR( returns, alphaVaR, lookback );
else
    error('generateData: varProcess undefined')
end  


returns = returns(lookback+1:length(returns));
%varSeries = varSeries0(lookback+1:length(varSeries0));
zSeries = zSeries0(lookback+1:length(zSeries0)); 

if(~isreal(returns))
    error(['generateData: returns are not real numbers. ','Underlying process: ',underlyingProcess,'. V: [',num2str(V), ']. GarchPar: [',num2str(garchPar),']']);
elseif(~isreal(varSeries))
	error(['generateData: varSerie are not real numbers. ','VaR process: ',varProcess,'. V: [',num2str(V), ']. GarchPar: [',num2str(garchPar),']']);
end
end

function [ returns sigmat ] = generateGarchReturns(dataLength, lookback, parameters, numberARCHTerms, numberGJRTerms, numberGARCHTerms, errorType)
%GENERATEGARCHRETURNS
%dataLength: length of generated data series
%parameters: array with parameters corresponding to number of ARCHterms
%etc. First parameter is value of constant [constant ARCHTerm1 ARCHTerm2... GJRTerm1 GJRTerm2... GARCHTerm1 GARCHTerm2...]
%errorType: 'NORMAL' or 'STUDENTST'
%
%See also TARCH, TARCH_SIMULATE

[returns sigmat] = tarch_simulate(dataLength+lookback, parameters, numberARCHTerms, numberGJRTerms, numberGARCHTerms, errorType);
end

function [ returns ] = generateNormalReturns(mean, std, dataLength, lookback)
%GENERATENORMALRETURNS
%

returns = randn(dataLength+lookback,1)*std + mean;
end

function [ returns ] = generateStudTReturns(mean, std, degFreedom, dataLength, lookback)
%GENERATESTUDENTTRETURNS
%
    
returns = trnd(degFreedom,dataLength+lookback,1)*sqrt((degFreedom-2)/degFreedom)*std+mean;
end
